@@ -121,7 +121,7 @@ GeomViolinHalf <- ggproto("GeomViolinHalf", Geom,
     weight = 1,
     colour = "grey20",
     fill = "white",
-    size = 0.5,
+    linewidth = 0.5,
     alpha = NA,
     linetype = "solid"
   ),
