@@ -22,7 +22,7 @@ data_plot.p_direction <- function(x, data = NULL, show_intercept = FALSE, ...) {
     data <- as.data.frame(data)
   }
 
-  if (ncol(data) > 1) {
+  if (ncol(data) > 1L) {
     levels_order <- rev(x$Parameter)
     data <- data[, x$Parameter, drop = FALSE]
     dataplot <- data.frame()
@@ -150,15 +150,13 @@ data_plot.p_direction <- function(x, data = NULL, show_intercept = FALSE, ...) {
 #'
 #' @return A ggplot2-object.
 #'
-#' @examplesIf require("rstanarm")
-#' \donttest{
+#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && require("rstanarm")
 #' library(rstanarm)
 #' library(bayestestR)
 #' set.seed(123)
-#' m <<- stan_glm(Sepal.Length ~ Petal.Width * Species, data = iris, refresh = 0)
+#' m <<- suppressWarnings(stan_glm(Sepal.Length ~ Petal.Width * Species, data = iris, refresh = 0))
 #' result <- p_direction(m)
 #' plot(result)
-#' }
 #' @importFrom ggplot2 .data
 #' @export
 plot.see_p_direction <- function(x,
@@ -172,7 +170,7 @@ plot.see_p_direction <- function(x,
   model <- .retrieve_data(x)
 
   # retrieve and prepare data for plotting
-  if (!"data_plot" %in% class(x)) {
+  if (!inherits(x, "data_plot")) {
     x <- data_plot(x, data = data, show_intercept = show_intercept)
   }
 
