@@ -27,7 +27,11 @@
 #'   theme_modern() +
 #'   scale_color_metro_c(palette = "rainbow")
 #' @export
-scale_color_metro <- function(palette = "complement", discrete = TRUE, reverse = FALSE, aesthetics = "color", ...) {
+scale_color_metro <- function(palette = "complement",
+                              discrete = TRUE,
+                              reverse = FALSE,
+                              aesthetics = "color",
+                              ...) {
   pal <- palette_metro(palette = palette, reverse = reverse)
 
   if (discrete) {
@@ -44,14 +48,34 @@ scale_color_metro <- function(palette = "complement", discrete = TRUE, reverse =
 
 #' @rdname scale_color_metro
 #' @export
-scale_color_metro_d <- function(palette = "complement", discrete = TRUE, reverse = FALSE, aesthetics = "color", ...) {
-  scale_color_metro(palette = palette, discrete = discrete, reverse = reverse, aesthetics = aesthetics, ...)
+scale_color_metro_d <- function(palette = "complement",
+                                discrete = TRUE,
+                                reverse = FALSE,
+                                aesthetics = "color",
+                                ...) {
+  scale_color_metro(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    aesthetics = aesthetics,
+    ...
+  )
 }
 
 #' @rdname scale_color_metro
 #' @export
-scale_color_metro_c <- function(palette = "complement", discrete = FALSE, reverse = FALSE, aesthetics = "color", ...) {
-  scale_color_metro(palette = palette, discrete = discrete, reverse = reverse, aesthetics = aesthetics, ...)
+scale_color_metro_c <- function(palette = "complement",
+                                discrete = FALSE,
+                                reverse = FALSE,
+                                aesthetics = "color",
+                                ...) {
+  scale_color_metro(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    aesthetics = aesthetics,
+    ...
+  )
 }
 
 #' @rdname scale_color_metro
@@ -76,7 +100,11 @@ scale_colour_metro_d <- scale_color_metro_d
 
 #' @rdname scale_color_metro
 #' @export
-scale_fill_metro <- function(palette = "complement", discrete = TRUE, reverse = FALSE, aesthetics = "fill", ...) {
+scale_fill_metro <- function(palette = "complement",
+                             discrete = TRUE,
+                             reverse = FALSE,
+                             aesthetics = "fill",
+                             ...) {
   pal <- palette_metro(palette = palette, reverse = reverse)
 
   if (discrete) {
@@ -89,14 +117,34 @@ scale_fill_metro <- function(palette = "complement", discrete = TRUE, reverse =
 
 #' @rdname scale_color_metro
 #' @export
-scale_fill_metro_d <- function(palette = "complement", discrete = TRUE, reverse = FALSE, aesthetics = "fill", ...) {
-  scale_fill_metro(palette = palette, discrete = discrete, reverse = reverse, aesthetics = aesthetics, ...)
+scale_fill_metro_d <- function(palette = "complement",
+                               discrete = TRUE,
+                               reverse = FALSE,
+                               aesthetics = "fill",
+                               ...) {
+  scale_fill_metro(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    aesthetics = aesthetics,
+    ...
+  )
 }
 
 #' @rdname scale_color_metro
 #' @export
-scale_fill_metro_c <- function(palette = "complement", discrete = FALSE, reverse = FALSE, aesthetics = "fill", ...) {
-  scale_fill_metro(palette = palette, discrete = discrete, reverse = reverse, aesthetics = aesthetics, ...)
+scale_fill_metro_c <- function(palette = "complement",
+                               discrete = FALSE,
+                               reverse = FALSE,
+                               aesthetics = "fill",
+                               ...) {
+  scale_fill_metro(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    aesthetics = aesthetics,
+    ...
+  )
 }
 
 
@@ -157,10 +205,31 @@ metro_colors <- function(...) {
 metro_palettes <- list(
   `full` = metro_colors(),
   `ice` = metro_colors("purple", "deep purple", "blue", "light blue"),
-  `rainbow` = metro_colors("purple", "deep purple", "blue", "light blue", "green", "light green", "amber", "orange", "deep orange", "red"),
+  `rainbow` = metro_colors(
+    "purple",
+    "deep purple",
+    "blue",
+    "light blue",
+    "green",
+    "light green",
+    "amber",
+    "orange",
+    "deep orange",
+    "red"
+  ),
   `contrast` = metro_colors("blue", "green", "amber", "purple", "red"),
   `light` = material_colors("light blue", "red", "yellow", "light green", "orange"),
-  `complement` = metro_colors("blue grey", "blue", "light blue", "teal", "green", "yellow", "amber", "orange", "red")
+  `complement` = metro_colors(
+    "blue grey",
+    "blue",
+    "light blue",
+    "teal",
+    "green",
+    "yellow",
+    "amber",
+    "orange",
+    "red"
+  )
 )
 
 
