@@ -1,5 +1,5 @@
 test_that("`print.see_performance_pp_check()` works", {
-  requiet("performance")
+  skip_if_not_or_load_if_installed("performance")
   model <- lm(Sepal.Length ~ Species * Petal.Width + Petal.Length,
     data = iris
   )
